@@ -5,8 +5,8 @@
 ;; Author: Julien Danjou <julien@danjou.info>
 ;; Maintainer: stardiviner <numbchild@gmail.com>
 ;; Keywords: contacts, org-mode, outlines, hypermedia, calendar
-;; Package-Version: 20250905.335
-;; Package-Revision: 41f10b9ab07f
+;; Package-Version: 20260114.754
+;; Package-Revision: 690ae7e735e1
 ;; Package-Requires: ((emacs "29.1") (org "9.7"))
 ;; Homepage: https://repo.or.cz/org-contacts.git
 ;;
@@ -193,7 +193,8 @@ This overrides `org-email-link-description-format' if set."
   "Default file for vcard export."
   :type 'file)
 
-(defcustom org-contacts-completion-enabled-mode-list '(org-mode message-mode mu4e-compose-mode)
+(defcustom org-contacts-completion-enabled-mode-list
+  '(org-mode message-mode mu4e-compose-mode notmuch-message-mode)
   "Enable or not the completion in `message-mode' with `org-contacts'."
   :type '(repeat symbol))
 
